@@ -17,6 +17,7 @@ def get_python_transformer_from_location(
     import_module_name: str,
     parameters: Dict[str, Any],
     progress_logger: Optional[ProgressLogger],
+    mapping_file_name: Optional[str] = None,
 ) -> Transformer:
     assert location
     # assert isinstance(parameters, dict)
@@ -43,6 +44,7 @@ def get_python_transformer_from_location(
     class_parameters = parameters.copy()
     class_parameters["parameters"] = parameters
     class_parameters["progress_logger"] = progress_logger
+    class_parameters["mapping_file_name"] = mapping_file_name
     if len(my_class_args) > 0 and len(class_parameters) > 0:
         return cast(
             Transformer,
@@ -55,7 +57,7 @@ def get_python_transformer_from_location(
 
 
 def get_python_function_from_location(
-    location: str, import_module_name: str
+    location: str, import_module_name: str, function_name: Optional[str] = None
 ) -> Callable[[Dict[str, Any]], Union[AutoMapperBase, List[AutoMapperBase]]]:
     assert location
     search = re.search(r"/library/", location)
@@ -66,9 +68,20 @@ def get_python_function_from_location(
     module = import_module(import_module_name, lib_path)
     md = module.__dict__
     # noinspection PyTypeChecker
+    my_functions: List[
+        Callable[[Dict[str, Any]], Union[AutoMapperBase, List[AutoMapperBase]]]
+    ] = (
+        [md[c] for c in md if isinstance(md[c], types.FunctionType)]
+        if not function_name
+        else [
+            md[c]
+            for c in md
+            if isinstance(md[c], types.FunctionType) and c == function_name
+        ]
+    )
     my_function: Callable[
         [Dict[str, Any]], Union[AutoMapperBase, List[AutoMapperBase]]
-    ] = [md[c] for c in md if isinstance(md[c], types.FunctionType)][0]
+    ] = my_functions[0]
     my_function_signature = signature(my_function)
     my_function_args = [
         param
