@@ -3,10 +3,9 @@ import math
 import os
 import shutil
 from pathlib import Path
-from typing import Dict, Any, Optional, Union, List
+from typing import Dict, Any, Optional, Union, List, cast
 
-# noinspection PyProtectedMember
-from pyspark import keyword_only
+from spark_pipeline_framework.utilities.capture_parameters import capture_parameters
 from pyspark.ml.param import Param
 from pyspark.sql.dataframe import DataFrame
 from spark_pipeline_framework.logger.yarn_logger import get_logger
@@ -18,7 +17,7 @@ from spark_pipeline_framework.transformers.framework_transformer.v1.framework_tr
 
 class FrameworkJsonSplitter(FrameworkTransformer):
     # noinspection PyUnusedLocal
-    @keyword_only
+    @capture_parameters
     def __init__(
         self,
         file_path: Union[Path, str],
@@ -119,12 +118,12 @@ class FrameworkJsonSplitter(FrameworkTransformer):
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def getFilePath(self) -> Union[Path, str]:
-        return self.getOrDefault(self.file_path)
+        return cast(Union[Path, str], self.getOrDefault(self.file_path))
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def getOutputFolder(self) -> Union[Path, str]:
-        return self.getOrDefault(self.output_folder)
+        return cast(Union[Path, str], self.getOrDefault(self.output_folder))
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def getMaxSizePerFileInMb(self) -> float:
-        return self.getOrDefault(self.max_size_per_file_in_mb)
+        return cast(float, self.getOrDefault(self.max_size_per_file_in_mb))
