@@ -21,6 +21,7 @@ class FrameworkPartitioner(FrameworkTransformer):
         name: Optional[str] = None,
         parameters: Optional[Dict[str, Any]] = None,
         progress_logger: Optional[ProgressLogger] = None,
+        force_partition: Optional[bool] = None,
     ):
         super().__init__(
             name=name, parameters=parameters, progress_logger=progress_logger
@@ -40,6 +41,9 @@ class FrameworkPartitioner(FrameworkTransformer):
         self.partition_by: Param[Optional[List[str]]] = Param(self, "partition_by", "")
         self._setDefault(partition_by=partition_by)
 
+        self.force_partition: Param[Optional[bool]] = Param(self, "force_partition", "")
+        self._setDefault(force_partition=None)
+
         kwargs = self._input_kwargs
         self.setParams(**kwargs)
 
@@ -47,10 +51,16 @@ class FrameworkPartitioner(FrameworkTransformer):
         view: str = self.getView()
         desired_partitions: Optional[int] = self.getDesiredPartitions()
         partition_by: Optional[List[str]] = self.getPartitionBy()
+        force_partition: Optional[bool] = self.getOrDefault(self.force_partition)
 
         result_df: DataFrame = df.sql_ctx.table(view)
         num_partitions: int = result_df.rdd.getNumPartitions()
         self.logger.info(f"view {view} has {num_partitions} partitions")
+
+        if not force_partition and desired_partitions == num_partitions:
+            result_df.createOrReplaceTempView(view)
+            return result_df
+
         if desired_partitions and partition_by:
             result_df = result_df.repartition(desired_partitions, partition_by[0])
         elif desired_partitions:
