@@ -1,5 +1,6 @@
 from typing import Optional, Dict, Any
 
+from spark_pipeline_framework.logger.log_level import LogLevel
 from spark_pipeline_framework.utilities.capture_parameters import capture_parameters
 from pyspark.ml.param import Param
 from pyspark.sql.dataframe import DataFrame
@@ -30,7 +31,9 @@ class FrameworkSqlTransformer(FrameworkTransformer):
         verify_count_remains_same: bool = False,
         mapping_file_name: Optional[str] = None,
         log_event: Optional[bool] = None,
+        log_event_level: Optional[LogLevel] = None,
         log_limit: Optional[int] = None,
+        desired_partitions: Optional[int] = None,
     ) -> None:
         """
         Runs the provided SQL
@@ -41,7 +44,10 @@ class FrameworkSqlTransformer(FrameworkTransformer):
         :param log_sql: whether to log the SQL to progress_logger
         :param log_result: whether to log the result to progress_logger
         :param verify_count_remains_same: whether to confirm the count of the rows remains the same after running SQL
-        :param log_event: whether to log an event with progress_logger with the contents of the output view
+        :param log_event: whether to log an event at TRACE level with progress_logger with the contents of
+                            the output view
+        :param log_event_level: the level to use for logging the event
+        :param desired_partitions: (Optional) Repartition the data after executing the sql
         """
         super().__init__(
             name=name, parameters=parameters, progress_logger=progress_logger
@@ -82,6 +88,16 @@ class FrameworkSqlTransformer(FrameworkTransformer):
         self.log_event: Param[Optional[bool]] = Param(self, "log_event", "")
         self._setDefault(log_event=None)
 
+        self.log_event_level: Param[Optional[LogLevel]] = Param(
+            self, "log_event_level", ""
+        )
+        self._setDefault(log_event_level=None)
+
+        self.desired_partitions: Param[Optional[int]] = Param(
+            self, "desired_partitions", ""
+        )
+        self._setDefault(desired_partitions=desired_partitions)
+
         kwargs = self._input_kwargs
         self.setParams(**kwargs)
 
@@ -92,7 +108,9 @@ class FrameworkSqlTransformer(FrameworkTransformer):
         progress_logger: Optional[ProgressLogger] = self.getProgressLogger()
         log_result: bool = self.getLogResult()
         log_event: Optional[bool] = self.getOrDefault(self.log_event)
+        log_event_level: Optional[LogLevel] = self.getOrDefault(self.log_event_level)
         log_limit: Optional[int] = self.getOrDefault(self.log_limit)
+        desired_partitions: Optional[int] = self.getOrDefault(self.desired_partitions)
 
         assert sql_text
         with ProgressLogMetric(
@@ -109,6 +127,11 @@ class FrameworkSqlTransformer(FrameworkTransformer):
                 self.logger.info(sql_text)
                 raise
 
+            if desired_partitions is not None:
+                num_partitions: int = df.rdd.getNumPartitions()
+                if num_partitions != desired_partitions:
+                    df = df.repartition(desired_partitions)
+
             if log_result:
                 log_limit = 10 if log_limit is None else log_limit
                 if log_limit and log_limit > 0:
@@ -122,11 +145,19 @@ class FrameworkSqlTransformer(FrameworkTransformer):
                     self.logger.info(message)
                     if progress_logger:
                         progress_logger.write_to_log(message)
-                        if log_event:
-                            progress_logger.log_event(
-                                event_name=name or view or self.__class__.__name__,
-                                event_text=message,
-                            )
+                        if log_event or log_event_level:
+                            if log_event_level:
+                                progress_logger.log_event(
+                                    event_name=name or view or self.__class__.__name__,
+                                    event_text=message,
+                                    log_level=log_event_level,
+                                )
+                            else:
+                                progress_logger.log_event(
+                                    event_name=name or view or self.__class__.__name__,
+                                    event_text=message,
+                                )
+
                         progress_logger.log_artifact(
                             key=f"{name or view}.csv", contents=message
                         )
